(** Common types. *)
(* Memory info command for virtual domains.
   (C) Copyright 2008 Richard W.M. Jones, Red Hat Inc.
   http://libvirt.org/

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   Common types.
 *)

(** A kernel image. *)
type image0 =
    int option				(* Domain ID, if known. *)
    * string				(* Domain name. *)
    * Virt_mem_utils.architecture	(* Architecture, eg. i386. *)
    * ([`Wordsize], [`Endian], [`HasMapping]) Virt_mem_mmap.t (* Memory map. *)

(** A kernel symbol. *)
type ksym = string

(** A kernel image, after finding kernel symbols. *)
type image1 =
    int option				(* Domain ID, if known. *)
    * string				(* Domain name. *)
    * Virt_mem_utils.architecture	(* Architecture, eg. i386. *)
    * ([`Wordsize], [`Endian], [`HasMapping]) Virt_mem_mmap.t (* Memory map. *)
    * (ksym -> Virt_mem_mmap.addr)	(* Kernel symbol lookup function. *)

(** A kernel image, after finding kernel version (like 'uname'). *)
type image2 =
    int option				(* Domain ID, if known. *)
    * string				(* Domain name. *)
    * Virt_mem_utils.architecture	(* Architecture, eg. i386. *)
    * ([`Wordsize], [`Endian], [`HasMapping]) Virt_mem_mmap.t (* Memory map. *)
    * (ksym -> Virt_mem_mmap.addr)	(* Kernel symbol lookup function. *)
    * utsname option			(* Kernel version, etc., if known. *)

and utsname = {
  kernel_name : string;
  nodename : string;
  kernel_release : string;
  kernel_version : string;
  machine : string;
  domainname : string;
}
